SimplePath

Struct SimplePath 

pub struct SimplePath(/* private fields */);
Simple, allocation-free path representation

Implementations

Source

impl SimplePath

pub fn new(path: &'static [&'static str]) -> Self

Construct, verifying validity

If the first component is an empty string, this is treated as a leading colon (e.g. ["", "abc", "Def"] == ::abc::Def`). No other component may be empty. At least one non-empty component is required.

Panics if requirements are not met.

pub fn matches(&self, path: &Path) -> bool

True if this matches a syn::Path

This must match the path exactly, with two exceptions:

  • if path has no leading colon but self does (empty first component), the paths may still match
  • if the first component of self is core or alloc but the first component of path is std, the paths may still match
pub fn matches_ident(&self, ident: &Ident) -> bool

True if the last component matches a syn::Ident

pub fn matches_ident_or_path(&self, path: &Path) -> bool

If input path has a single component with no leading colon, then match via Self::matches_ident; otherwise match via Self::matches.